@@ -246,9 +246,9 @@ class RgbToLab(ImageFilter):
     ----------
     img : PIL.Image.Image
         Input image
-    illuminant : {“A”, “D50”, “D55”, “D65”, “D75”, “E”}, optional
+    illuminant : {"A", "B", "C", "D50", "D55", "D65", "D75", "E"}, optional
         The name of the illuminant (the function is NOT case sensitive).
-    observer : {“2”, “10”}, optional
+    observer : {"2", "10", "R"}, optional
         The aperture angle of the observer.
 
     Returns
@@ -635,10 +635,10 @@ class LabToRgb(ImageFilter):
     ----------
     img : np.array
         Input image in Lab space.
-    illuminant : {“A”, “D50”, “D55”, “D65”, “D75”, “E”}, optional
+    illuminant : {"A", "B", "C", "D50", "D55", "D65", "D75", "E"}, optional
         The name of the illuminant (the function is NOT case sensitive). Default is
         "D65".
-    observer : {“2”, “10”}, optional
+    observer : {"2", "10", "R"}, optional
         The aperture angle of the observer. Default is "2".
 
     Returns
@@ -704,7 +704,9 @@ class KmeansSegmentation(ImageFilter):
     By using K-means segmentation (color/space proximity) each segment is colored based
     on the average color for that segment.
 
-    .. figure:: https://user-images.githubusercontent.com/31658006/116543486-37fde100-a8ee-11eb-8695-75fae5767de1.jpeg
+    .. figure:: https://user-images.githubusercontent.com/20052362/144853490-741deb95-cd84-47b0-8227-38e6091753d8.png
+        :figwidth: 60 %
+        :align: center
 
     Parameters
     ---------
@@ -753,7 +755,9 @@ class RagThreshold(ImageFilter):
     the segments, combine similar regions based on threshold value,
     and then output these resulting region segments.
 
-    .. figure:: https://user-images.githubusercontent.com/31658006/116553449-6a154000-a8fa-11eb-8e74-b9d711e79113.jpeg
+    .. figure:: https://user-images.githubusercontent.com/20052362/144852689-6098a415-1714-4abf-a361-485761647349.png
+        :figwidth: 60 %
+        :align: center
 
     Parameters
     ----------
@@ -765,12 +769,18 @@ class RagThreshold(ImageFilter):
         Color proximity versus space proximity factor. Default is 10.0
     threshold : int, optional
         Threshold value for combining regions. Default is 9.
+    return_labels : bool, optional
+        If True, returns a labeled array where the value denotes segment
+        membership. Otherwise, returns a PIL image where each segment is colored
+        by the average color in it. Default is False.
 
     Returns
     -------
-    PIL.Image.Image
+    PIL.Image.Image, if not ``return_labels``
         Each segment has been colored based on the average
         color for that segment (and similar segments have been combined).
+    np.ndarray, if ``return_labels``
+        Value denotes segment membership.
 
     Raises
     ------
@@ -787,14 +797,30 @@ class RagThreshold(ImageFilter):
     """  # noqa
 
     def __init__(
-        self, n_segments: int = 800, compactness: float = 10.0, threshold: int = 9
-    ) -> PIL.Image.Image:
+        self,
+        n_segments: int = 800,
+        compactness: float = 10.0,
+        threshold: int = 9,
+        return_labels: bool = False,
+    ) -> None:
         self.n_segments = n_segments
         self.compactness = compactness
         self.threshold = threshold
+        self.return_labels = return_labels
 
-    def __call__(self, img: PIL.Image.Image) -> PIL.Image.Image:
-        return F.rag_threshold(img, self.n_segments, self.compactness, self.threshold)
+    def __call__(
+        self,
+        img: PIL.Image.Image,
+        mask: np.ndarray = None,
+    ) -> Union[PIL.Image.Image, np.ndarray]:
+        return F.rag_threshold(
+            img,
+            n_segments=self.n_segments,
+            compactness=self.compactness,
+            threshold=self.threshold,
+            mask=mask,
+            return_labels=self.return_labels,
+        )
 
 
 class HysteresisThreshold(ImageFilter):
@@ -1034,7 +1060,7 @@ class CannyEdges(ImageFilter):
 
     Note that input image must be 2D.
 
-    .. figure:: https://user-images.githubusercontent.com/31658006/116542613-1d773800-a8ed-11eb-9005-4c0ad8d051b8.png
+    .. figure:: https://user-images.githubusercontent.com/20052362/144851746-3332560c-bd61-4b5a-baa3-6a8a528c0db0.png
 
     Parameters
     ----------
