@@ -17,13 +17,12 @@
 # ------------------------------------------------------------------------
 from abc import ABC, abstractmethod
 from functools import lru_cache
-from typing import List, Union
+from typing import Iterable, List, Union
 
 import numpy as np
 
-import histolab
-
 from .filters.compositions import FiltersComposition
+from .filters.image_filters import Compose, Filter
 from .slide import Slide
 from .tile import Tile
 from .types import Region
@@ -65,13 +64,25 @@ class BinaryMask(ABC):
 class BiggestTissueBoxMask(BinaryMask):
     r"""Object that represents the box containing the largest contiguous tissue area.
 
-    Internally, this class automatically detects the tissue regions via a predefined
-    sequence of filters, and then retain the largest connected component.
-
     .. figure:: https://user-images.githubusercontent.com/31658006/116549379-b14d0200-a8f5-11eb-85b1-46abc14c73bf.jpeg
 
     """  # noqa
 
+    def __init__(self, *filters: Iterable[Filter]) -> None:
+        """Create a new tissue mask and then retain the largest connected component.
+
+        If custom image filters are specified, those are used instead the default ones.
+        By default, the tissue within the slide or tile is automatically detected
+        through a predefined chain of filters.
+
+        Parameters
+        ----------
+        *filters : Iterable[Filter]
+            Custom filters to derive a BiggestTissueBoxMask which overwrite the default
+            pipeline.
+        """
+        self.custom_filters = filters
+
     @lru_cache(maxsize=100)
     def _mask(self, slide) -> np.ndarray:
         """Return the thumbnail box mask containing the largest contiguous tissue area.
@@ -88,8 +99,13 @@ class BiggestTissueBoxMask(BinaryMask):
             The dimensions are those of the thumbnail.
         """
         thumb = slide.thumbnail
-        filters = FiltersComposition(histolab.slide.Slide).tissue_mask_filters
-        thumb_mask = filters(thumb)
+
+        if len(self.custom_filters) == 0:
+            composition = FiltersComposition(Slide)
+        else:
+            composition = FiltersComposition(Compose, *self.custom_filters)
+
+        thumb_mask = composition.tissue_mask_filters(thumb)
         regions = regions_from_binary_mask(thumb_mask)
         biggest_region = self._regions(regions, n=1)[0]
         biggest_region_coordinates = region_coordinates(biggest_region)
@@ -132,10 +148,22 @@ class BiggestTissueBoxMask(BinaryMask):
 
 
 class TissueMask(BinaryMask):
-    """Object that represent the whole tissue area mask.
+    """Object that represent the whole tissue area mask."""
 
-    The tissue within the slide or tile is automatically detected through a predefined
-    chain of filters."""
+    def __init__(self, *filters: Iterable[Filter]) -> None:
+        """
+        Create a new tissue mask.
+
+        If custom image filters are specified, those are used instead the default ones.
+        By default, the tissue within the slide or tile is automatically detected
+        through a predefined chain of filters.
+
+        Parameters
+        ----------
+        *filters : Iterable[Filter]
+            Custom filters to derive a TissueMask which overwrite the default pipeline.
+        """
+        self.custom_filters = filters
 
     def __call__(self, obj: Union[Slide, Tile]) -> np.ndarray:
         """Apply a predefined chain of filters to calculate the tissue area mask.
@@ -178,8 +206,14 @@ class TissueMask(BinaryMask):
             Binary mask of the tissue area. The dimensions are those of the thumbnail.
         """
         thumb = slide.thumbnail
-        filters = FiltersComposition(histolab.slide.Slide).tissue_mask_filters
-        thumb_mask = filters(thumb)
+
+        # Generate appropriate composition of filter
+        if len(self.custom_filters) == 0:
+            composition = FiltersComposition(Slide)
+        else:
+            composition = FiltersComposition(Compose, *self.custom_filters)
+
+        thumb_mask = composition.tissue_mask_filters(thumb)
         return thumb_mask
 
     @lru_cache(maxsize=100)
@@ -197,4 +231,10 @@ class TissueMask(BinaryMask):
         mask: np.ndarray
             Binary mask of the tissue area. The dimensions are those of the tile.
         """
+
+        # Check if calculating a customized mask is required.
+        # Otherwise, fall back to the default one.
+        if len(self.custom_filters) > 0:
+            custom_filters = FiltersComposition(Compose, *self.custom_filters)
+            return tile.calculate_tissue_mask(custom_filters)
         return tile.tissue_mask
