@@ -135,7 +135,7 @@ class Slide:
         """
         if self._use_largeimage:
             if self._metadata.get("mm_x") is not None:
-                return self._metadata["mm_x"] * (10 ** 3)
+                return self._metadata["mm_x"] * (10**3)
             raise ValueError(
                 "Unknown scan resolution! This slide is missing metadata "
                 "needed for calculating the scanning resolution. Without "
@@ -497,7 +497,11 @@ class Slide:
             The slide thumbnail.
         """
         if self._use_largeimage:
-            thumb_bytes, _ = self._tile_source.getThumbnail(encoding="PNG")
+            thumb_bytes, _ = self._tile_source.getThumbnail(
+                encoding="PNG",
+                width=self._thumbnail_size[0],
+                height=self._thumbnail_size[1],
+            )
             thumbnail = self._bytes2pil(thumb_bytes).convert("RGB")
             return thumbnail
 
