@@ -482,10 +482,10 @@ class GridTiler(Tiler):
         for i in range(n_tiles_row):
             for j in range(n_tiles_column):
                 x_ul_lvl = (
-                    bbox_coordinates_lvl.x_ul + tile_w_lvl * i - self.pixel_overlap
+                    bbox_coordinates_lvl.x_ul + tile_w_lvl * i - self.pixel_overlap * i
                 )
                 y_ul_lvl = (
-                    bbox_coordinates_lvl.y_ul + tile_h_lvl * j - self.pixel_overlap
+                    bbox_coordinates_lvl.y_ul + tile_h_lvl * j - self.pixel_overlap * j
                 )
 
                 x_ul_lvl = np.clip(x_ul_lvl, bbox_coordinates_lvl.x_ul, None)
