@@ -7,7 +7,7 @@ from unittest.mock import call
 import numpy as np
 import pytest
 
-from histolab.exceptions import LevelError, TileSizeError
+from histolab.exceptions import LevelError, TileSizeOrCoordinatesError
 from histolab.masks import BiggestTissueBoxMask
 from histolab.scorer import RandomScorer
 from histolab.slide import Slide
@@ -30,18 +30,33 @@ from ..unitutil import (
 
 
 class Describe_RandomTiler:
-    @pytest.mark.parametrize("level", (2, -2))
-    def it_constructs_from_args(self, level, request):
+    @pytest.mark.parametrize("level, mpp", ((2, None), (-2, None), (2, 0.5)))
+    def it_constructs_from_args(self, level, mpp, request):
         _init = initializer_mock(request, RandomTiler)
 
-        random_tiler = RandomTiler((512, 512), 10, level, 7, True, "", ".png", int(1e4))
+        random_tiler = RandomTiler(
+            tile_size=(512, 512), n_tiles=10, level=level, mpp=mpp
+        )
 
         _init.assert_called_once_with(
-            ANY, (512, 512), 10, level, 7, True, "", ".png", int(1e4)
+            random_tiler, tile_size=(512, 512), n_tiles=10, level=level, mpp=mpp
         )
         assert isinstance(random_tiler, RandomTiler)
         assert isinstance(random_tiler, Tiler)
 
+    @pytest.mark.parametrize(
+        "level, mpp, expected_level, expected_mpp",
+        ((2, None, 2, None), (None, 0.5, 0, 0.5), (2, 0.5, 0, 0.5)),
+    )
+    def it_knows_when_mpp_supercedes_level(
+        self, level, mpp, expected_level, expected_mpp
+    ):
+
+        random_tiler = RandomTiler((512, 512), 10, level=level, mpp=mpp)
+
+        assert random_tiler.level == expected_level
+        assert random_tiler.mpp == expected_mpp
+
     def but_it_has_wrong_tile_size_value(self):
         with pytest.raises(ValueError) as err:
             RandomTiler((512, -1), 10, 0)
@@ -51,7 +66,7 @@ class Describe_RandomTiler:
 
     def or_it_has_not_available_level_value(self, tmpdir):
         slide, _ = base_test_slide(tmpdir, PILIMG.RGB_RANDOM_COLOR_500X500)
-        random_tiler = RandomTiler((128, 128), 10, 3)
+        random_tiler = RandomTiler(tile_size=(128, 128), n_tiles=10, level=3)
         binary_mask = BiggestTissueBoxMask()
 
         with pytest.raises(LevelError) as err:
@@ -392,10 +407,10 @@ class Describe_RandomTiler:
         random_tiler = RandomTiler((50, 52), n_tiles=10, level=0)
         binary_mask = BiggestTissueBoxMask()
 
-        with pytest.raises(TileSizeError) as err:
+        with pytest.raises(TileSizeOrCoordinatesError) as err:
             random_tiler.extract(slide, binary_mask)
 
-        assert isinstance(err.value, TileSizeError)
+        assert isinstance(err.value, TileSizeOrCoordinatesError)
         assert (
             str(err.value)
             == f"Tile size (50, 52) is larger than slide size {size} at level 0"
@@ -410,16 +425,31 @@ class Describe_RandomTiler:
 
 
 class Describe_GridTiler:
-    @pytest.mark.parametrize("level", (2, -2))
-    def it_constructs_from_args(self, level, request):
+    @pytest.mark.parametrize("level, mpp", ((2, None), (-2, None), (2, 0.5)))
+    def it_constructs_from_args(self, level, mpp, request):
         _init = initializer_mock(request, GridTiler)
 
-        grid_tiler = GridTiler((512, 512), level, True, 80, 0, "", ".png")
+        grid_tiler = GridTiler((512, 512), level, True, 80, 0, "", ".png", mpp=mpp)
 
-        _init.assert_called_once_with(ANY, (512, 512), level, True, 80, 0, "", ".png")
+        _init.assert_called_once_with(
+            ANY, (512, 512), level, True, 80, 0, "", ".png", mpp=mpp
+        )
         assert isinstance(grid_tiler, GridTiler)
         assert isinstance(grid_tiler, Tiler)
 
+    @pytest.mark.parametrize(
+        "level, mpp, expected_level, expected_mpp",
+        ((2, None, 2, None), (None, 0.5, 0, 0.5), (2, 0.5, 0, 0.5)),
+    )
+    def it_knows_when_mpp_supercedes_level(
+        self, level, mpp, expected_level, expected_mpp
+    ):
+
+        tiler = GridTiler((512, 512), level=level, mpp=mpp)
+
+        assert tiler.level == expected_level
+        assert tiler.mpp == expected_mpp
+
     def but_it_has_wrong_tile_size_value(self):
         with pytest.raises(ValueError) as err:
             GridTiler((512, -1))
@@ -582,8 +612,8 @@ class Describe_GridTiler:
 
         assert _extract_tile.call_args_list == (
             [
-                call(slide, CP(0, 0, 10, 10), 0, (10, 10)),
-                call(slide, CP(0, 0, 10, 10), 0, (10, 10)),
+                call(slide, CP(0, 0, 10, 10), tile_size=(10, 10), level=0, mpp=None),
+                call(slide, CP(0, 0, 10, 10), tile_size=(10, 10), level=0, mpp=None),
             ]
         )
         assert _has_enough_tissue.call_args_list == [call(tile1, 60), call(tile2, 60)]
@@ -638,8 +668,8 @@ class Describe_GridTiler:
 
         assert _extract_tile.call_args_list == (
             [
-                call(slide, CP(0, 0, 10, 10), 0, (10, 10)),
-                call(slide, CP(0, 0, 10, 10), 0, (10, 10)),
+                call(slide, CP(0, 0, 10, 10), tile_size=(10, 10), level=0, mpp=None),
+                call(slide, CP(0, 0, 10, 10), tile_size=(10, 10), level=0, mpp=None),
             ]
         )
         _has_enough_tissue.assert_not_called()
@@ -747,10 +777,10 @@ class Describe_GridTiler:
         grid_tiler = GridTiler((50, 52), level=0)
         binary_mask = BiggestTissueBoxMask()
 
-        with pytest.raises(TileSizeError) as err:
+        with pytest.raises(TileSizeOrCoordinatesError) as err:
             grid_tiler.extract(slide, binary_mask)
 
-        assert isinstance(err.value, TileSizeError)
+        assert isinstance(err.value, TileSizeOrCoordinatesError)
         assert (
             str(err.value)
             == f"Tile size (50, 52) is larger than slide size {size} at level 0"
@@ -846,10 +876,12 @@ class Describe_ScoreTiler:
     def it_constructs_from_args(self, request):
         _init = initializer_mock(request, ScoreTiler)
         rs = RandomScorer()
-        score_tiler = ScoreTiler(rs, (512, 512), 4, 2, True, 80, 0, "", ".png")
+        score_tiler = ScoreTiler(
+            rs, (512, 512), 4, 2, True, 80, 0, "", ".png", mpp=None
+        )
 
         _init.assert_called_once_with(
-            ANY, rs, (512, 512), 4, 2, True, 80, 0, "", ".png"
+            ANY, rs, (512, 512), 4, 2, True, 80, 0, "", ".png", mpp=None
         )
 
         assert isinstance(score_tiler, ScoreTiler)
@@ -1081,8 +1113,8 @@ class Describe_ScoreTiler:
         score_tiler.extract(slide, binary_mask)
 
         assert _extract_tile.call_args_list == [
-            call(slide, coords, 0, (10, 10)),
-            call(slide, coords, 0, (10, 10)),
+            call(slide, coords, tile_size=(10, 10), level=0, mpp=None),
+            call(slide, coords, tile_size=(10, 10), level=0, mpp=None),
         ]
         _tiles_generator.assert_called_with(score_tiler, slide, binary_mask)
         assert _tile_filename.call_args_list == [
@@ -1117,10 +1149,10 @@ class Describe_ScoreTiler:
         score_tiler = ScoreTiler(None, (50, 52), 2, 0)
         binary_mask = BiggestTissueBoxMask()
 
-        with pytest.raises(TileSizeError) as err:
+        with pytest.raises(TileSizeOrCoordinatesError) as err:
             score_tiler.extract(slide, binary_mask)
 
-        assert isinstance(err.value, TileSizeError)
+        assert isinstance(err.value, TileSizeOrCoordinatesError)
         assert (
             str(err.value)
             == f"Tile size (50, 52) is larger than slide size {size} at level 0"
@@ -1185,8 +1217,8 @@ class Describe_ScoreTiler:
         score_tiler.extract(slide, binary_mask, "report.csv")
 
         assert _extract_tile.call_args_list == [
-            call(slide, coords, 0, (10, 10)),
-            call(slide, coords, 0, (10, 10)),
+            call(slide, coords, tile_size=(10, 10), level=0, mpp=None),
+            call(slide, coords, tile_size=(10, 10), level=0, mpp=None),
         ]
         _tiles_generator.assert_called_with(score_tiler, slide, binary_mask)
         assert _tile_filename.call_args_list == [
